<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package bizmark
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="http://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<div id="page" class="site">

<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'bizmark' ); ?></a>
	
<div class="outerContainer">

	<header id="masthead" class="site-header">
		
		<div class="responsive-container">
		
			<div class="site-branding">
				
				<?php
				
					$custom_logo_id = get_theme_mod( 'custom_logo' );
					$logo = wp_get_attachment_image_src( $custom_logo_id , 'full' );
					if ( has_custom_logo() ) {
							echo '<a href="' . esc_url( home_url( '/' ) ) . '"><img src="'. esc_url( $logo[0] ) .'"></a>';
					} else {
							echo '<h1>'. get_bloginfo( 'name' ) .'</h1>';
							$bizmark_description = get_bloginfo( 'description', 'display' );
							if ( $bizmark_description || is_customize_preview() ){
								echo '<p class="site-description">' . $bizmark_description . '</p>';
							}
					}			
				
				?>
				
				<span class="menu-button"></span>

			</div><!-- .site-branding -->

			<nav id="site-navigation" class="main-navigation">
				
				<div class="menu-container">
				
					<?php
					wp_nav_menu( array(
						'theme_location' => 'menu-1',
						'menu_id'        => 'primary-menu',
						'depth' => 1,
						'container_class' => 'bizmark-menu',
					) );
					?>
				
				</div><!-- .menu-container -->

			</nav><!-- #site-navigation -->
		
		</div>
		
	</header><!-- #masthead -->
	
	<?php 

		if( is_front_page() && 'page' == get_option( 'show_on_front' ) ):

		if( 'no' != get_theme_mod('bizmark_show_slider') ): 
		
		$bizmarkHeaderPostTitle = '';
		$bizmarkHeaderPostDesc = '';
		$bizmarkHeaderPostUrl = '';
		$bizmarkHeaderPostImage = '';
		
		if( '' != get_theme_mod('bizmark_slider_post') && 'select' != get_theme_mod('bizmark_slider_post') ){
			
			$bizmarkHeaderPostId = get_theme_mod('bizmark_slider_post');
			
			if( ctype_alnum($bizmarkHeaderPostId) ){

				$bizmarkHeaderPost = get_post( $bizmarkHeaderPostId );
			
				$bizmarkHeaderPostTitle = $bizmarkHeaderPost->post_title;
				$bizmarkHeaderPostDesc = $bizmarkHeaderPost->post_excerpt;
				$bizmarkHeaderPostUrl = get_permalink( $bizmarkHeaderPostId );
				
				if( has_post_thumbnail($bizmarkHeaderPostId) ){
					$bizmarkHeaderPostImage = wp_get_attachment_image_src( get_post_thumbnail_id( $bizmarkHeaderPostId ), 'full' );
					$bizmarkHeaderPostImage = $bizmarkHeaderPostImage[0];
				}
				
			}
			
		}
		
		
		
	?>
	<div class="header-container">
	
		<div class="frontpage-container">
		
			<div class="responsive-container">
			
				<div class="frontpage-image">
					
					<?php 
						
						if( '' != $bizmarkHeaderPostImage ){
							echo '<img src="' . esc_url($bizmarkHeaderPostImage) . '" />';
						} 
						
					?>
					
				</div><!-- .frontpage-image -->
				
				<div class="frontpage-text">
					
					<h1><?php echo esc_html($bizmarkHeaderPostTitle); ?></h1>
					<p><?php echo esc_html($bizmarkHeaderPostDesc); ?></p>
					<p><a href="<?php echo esc_url($bizmarkHeaderPostUrl); ?>">Read More</a></p>
					
				</div><!-- .frontpage-text -->			
			
			</div>
		
		</div><!-- .frontpage-container -->
	
	</div><!-- .header-container -->
	<?php endif; endif; ?>

	<div id="content" class="site-content">
